@@ -1,7 +1,7 @@
 import click
 
-from ..utils import command
 from ..repo import RepoManager
+from ..utils import command
 
 
 @click.command()
@@ -10,5 +10,5 @@ def remote(ctx):
     """Display repo github path
     """
     with command():
-        m = RepoManager(ctx.obj['agile'])
+        m = RepoManager(ctx.obj["agile"])
         click.echo(m.github_repo().repo_path)
